@@ -14,7 +14,7 @@ use File::Glob qw(:bsd_glob);
 use POSIX qw(strftime);                                                         # http://www.cplusplus.com/reference/ctime/strftime/
 use Data::Dump qw(dump);
 
-our $VERSION = '2017.201';
+our $VERSION = '2017.221';
 
 &saveToS3('DataTableText') if 0;                                                # Save code
 
@@ -381,6 +381,19 @@ sub trim($)
   $string =~ s/\A\s+//r =~ s/\s+\Z//r
  }
 
+#-------------------------------------------------------------------------------
+# Pad a string with blanks to a multiple of a specified length
+#-------------------------------------------------------------------------------
+
+sub pad($$)
+ {my ($string, $length) = @_;
+  $string =~ s/\s+\Z//;
+  my $l = length($string);
+  return $string if $l % $length == 0;
+  my $p = $length - $l % $length;
+  $string .= ' ' x $p;
+ }
+
 #1 Documented methods
 
 sub nws($)                                                                      # Normalize white space in a string to make comparisons easier
@@ -504,7 +517,7 @@ extractDocumentation fileList fileSize formatTableBasic
 genLValueArrayMethods genLValueHashMethods genLValueScalarMethods genLValueScalarMethodsWithDefaultValues
 indentString
 loadArrayArrayFromLines loadArrayFromLines  loadHashArrayFromLines loadHashFromLines
-makePath nws powerOfTwo
+makePath nws pad powerOfTwo
 readBinaryFile readFile saveToS3 timeStamp trim writeBinaryFile writeFile);
 %EXPORT_TAGS  = (all=>[@EXPORT, @EXPORT_OK]);
 
@@ -616,7 +629,7 @@ modified under the same terms as Perl itself.
 =cut
 
 __DATA__
-use Test::More tests => 40;
+use Test::More tests => 45;
 if (1)                                                                          # Unicode
  {use utf8;
   my $z = "𝝰𝝱𝝲";
@@ -766,3 +779,9 @@ ok  containingPowerOfTwo(3) == 2;
 ok  containingPowerOfTwo(4) == 2;
 ok  containingPowerOfTwo(5) == 3;
 ok  containingPowerOfTwo(7) == 3;
+
+ok  pad('abc  ', 2).'=' eq "abc =";
+ok  pad('abc  ', 3).'=' eq "abc=";
+ok  pad('abc  ', 4).'=' eq "abc =";
+ok  pad('abc  ', 5).'=' eq "abc  =";
+ok  pad('abc  ', 6).'=' eq "abc   =";
